@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -435,7 +435,7 @@ public class ChronosCopyTask implements CopyUserTaskService {
         CalendarUser calendarUser = new CalendarUser();
         calendarUser.setEntity(dstUsrId);
         calendarUser.setUri(ResourceId.forUser(dstCtx.getContextId(), dstUsrId));
-        if (srcCalendarUser.getEntity() == srcUsrId) {
+        if (null != srcCalendarUser && srcCalendarUser.getEntity() == srcUsrId) {
             if (Strings.isNotEmpty(srcCalendarUser.getEMail())) {
                 calendarUser.setEMail(srcCalendarUser.getEMail());
             }
