@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -184,9 +184,9 @@ public class ContactCopyTask implements CopyUserTaskService {
                     for (final DistributionListEntryObject entry : distributionList) {
                         int i = 1;
                         stmt.setInt(i++, contact.getObjectID());
-                        setIntOrNull(i++, stmt, entry.getEntryID());
+                        setIntOrNull(i++, stmt, null == entry.getEntryID() ? 0 : Strings.parseUnsignedInt(entry.getEntryID()));
                         setIntOrNull(i++, stmt, entry.getEmailfield());
-                        setIntOrNull(i++, stmt, entry.getFolderID());
+                        setIntOrNull(i++, stmt, null == entry.getFolderID() ? 0 : Strings.parseUnsignedInt(entry.getFolderID()));
                         setStringOrNull(i++, stmt, entry.getDisplayname());
                         setStringOrNull(i++, stmt, entry.getLastname());
                         setStringOrNull(i++, stmt, entry.getFirstname());
@@ -302,19 +302,20 @@ public class ContactCopyTask implements CopyUserTaskService {
             if (contact.containsDistributionLists()) {
                 final DistributionListEntryObject[] distributionList = contact.getDistributionList();
                 for (final DistributionListEntryObject entry : distributionList) {
-                    final int entryId = entry.getEntryID();
-                    if (entryId > 0) {
+                    final String entryId = entry.getEntryID();
+                    final int integerEntryId = Strings.parseUnsignedInt(entryId);
+                    if (integerEntryId > 0) {
                         /*
                          * This list entry refers to an existing contact.
                          * If this contact isn't visible to the moved user, the entry becomes an external member.
                          */
-                        final Contact dlistContact = contacts.get(I(entryId));
+                        final Contact dlistContact = contacts.get(I(integerEntryId));
                         if (dlistContact == null) {
-                            entry.setEntryID(-1);
+                            entry.setEntryID(null);
                             entry.setEmailfield(-1);
-                            entry.setFolderID(-1);
+                            entry.setFolderID(null);
                         } else {
-                            entry.setEntryID(dlistContact.getObjectID());
+                            entry.setEntryID(dlistContact.getId(true));
                         }
                     }
                 }
@@ -372,9 +373,11 @@ public class ContactCopyTask implements CopyUserTaskService {
                 int i = 1;
                 final DistributionListEntryObject entry = new DistributionListEntryObject();
                 final int contactId = rs.getInt(i++);
-                entry.setEntryID(getIntOrNegative(i++, rs));
+                int entryId = getIntOrNegative(i++, rs);
+                entry.setEntryID(entryId < 1 ? null : I(entryId).toString());
                 entry.setEmailfield(getIntOrNegative(i++, rs));
-                entry.setFolderID(getIntOrNegative(i++, rs));
+                int folderID = getIntOrNegative(i++, rs);
+                entry.setFolderID(0 < folderID ? Integer.toString(folderID) : null);
                 entry.setDisplayname(rs.getString(i++));
                 entry.setLastname(rs.getString(i++));
                 entry.setFirstname(rs.getString(i++));
