@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -62,45 +62,45 @@ public class FolderCopyTask implements CopyUserTaskService {
 
     private static final String SELECT_FOLDERS =
         "SELECT "+
-            "fuid, parent, fname, module, type, creating_date, " +
-            "changing_date, changed_from, permission_flag, " +
-            "subfolder_flag, default_flag " +
+            "`fuid`, `parent`, `fname`, `module`, `type`, `creating_date`, " +
+            "`changing_date`, `changed_from`, `permission_flag`, " +
+            "`subfolder_flag`, `default_flag` " +
         "FROM " +
-            "oxfolder_tree " +
+            "`oxfolder_tree` " +
         "WHERE " +
-            "cid = ? AND created_from = ? AND (module = 8 OR type = 1)";
+            "`cid` = ? AND `created_from` = ? AND (`module` = 8 OR `type` = 1)";
 
     private static final String INSERT_FOLDERS =
         "INSERT INTO " +
-            "oxfolder_tree " +
-            "(fuid, cid, parent, fname, module, type, creating_date, " +
-            "created_from, changing_date, changed_from, permission_flag, " +
-            "subfolder_flag, default_flag) " +
+            "`oxfolder_tree` " +
+            "(`fuid`, `cid`, `parent`, `fname`, `module`, `type`, `creating_date`, " +
+            "`created_from`, `changing_date`, `changed_from`, `permission_flag`, " +
+            "`subfolder_flag`, `default_flag`) " +
         "VALUES " +
             "(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
 
     private static final String SELECT_VIRTUAL_FOLDERS =
         "SELECT " +
-            "tree, folderId, parentId, " +
-            "name, lastModified, modifiedBy, shadow, sortNum " +
+            "`tree`, `folderId`, `parentId`, " +
+            "`name`, `lastModified`, `modifiedBy`, `shadow`, `sortNum` " +
         "FROM " +
-            "virtualTree " +
+            "`virtualTree` " +
         "WHERE " +
-            "cid = ? " +
+            "`cid` = ? " +
         "AND " +
-            "user = ?";
+            "`user` = ?";
 
     private static final String INSERT_VIRTUAL_FOLDERS =
         "INSERT INTO " +
-            "virtualTree " +
-            "(cid, tree, user, folderId, parentId, name, lastModified, modifiedBy, shadow, sortNum) " +
+            "`virtualTree` " +
+            "(`cid`, `tree`, `user`, `folderId`, `parentId`, `name`, `lastModified`, `modifiedBy`, `shadow`, `sortNum`) " +
         "VALUES " +
             "(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
 
     private static final String INSERT_PERMISSIONS =
         "INSERT INTO " +
             "oxfolder_permissions " +
-            "(cid, fuid, permission_id, fp, orp, owp, odp, admin_flag, group_flag, system) " +
+            "(`cid`, `fuid`, `permission_id`, `fp`, `orp`, `owp`, `odp`, `admin_flag`, `group_flag`, `system`) " +
         "VALUES " +
             "(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
 
